# QuoteBook
Simple PyQt5 based program used to store quotes.

Each quote can in addition store information about author, title, characters, category, date and tags.
Quotes are stored in a json file as a list of dictionaries.